@@ -4,12 +4,6 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-from builtins import range
-
-from future import standard_library
-
-standard_library.install_aliases()
-
 # Standard
 import importlib
 import signal
@@ -30,13 +24,15 @@ from django import db
 import signing
 import tasks
 
-from django_q.conf import Conf, logger, psutil, get_ppid, rollbar
+from django_q.compat import range
+from django_q.conf import Conf, logger, psutil, get_ppid, error_reporter, rollbar
 from django_q.models import Task, Success, Schedule
 from django_q.status import Stat, Status
 from django_q.brokers import get_broker
 from django_q.signals import pre_execute
 
 
+
 class Cluster(object):
     def __init__(self, broker=None):
         self.broker = broker or get_broker()
@@ -369,6 +365,8 @@ def worker(task_queue, result_queue, timer, timeout=Conf.TIMEOUT):
                 f = getattr(m, func)
             except (ValueError, ImportError, AttributeError) as e:
                 result = (e, False)
+                if error_reporter:
+                    error_reporter.report()
                 if rollbar:
                     rollbar.report_exc_info()
         # We're still going
@@ -384,6 +382,8 @@ def worker(task_queue, result_queue, timer, timeout=Conf.TIMEOUT):
                 result = (res, True)
             except Exception as e:
                 result = ('{}'.format(e), False)
+                if error_reporter:
+                    error_reporter.report()
                 if rollbar:
                     rollbar.report_exc_info()
         # Process result
